@@ -1,6 +1,6 @@
 from typing import Optional
 
-from pydantic import BaseModel
+from .base_model import BaseModel
 
 MODEL_TYPE = "contact_info"
 
