@@ -1,6 +1,6 @@
 from typing import Optional, Union
 
-from pydantic import BaseModel
+from .base_model import BaseModel
 
 from . import response as response_models
 from .languages import CreateAPILanguagesFields
@@ -13,7 +13,6 @@ MODEL_TYPE = "educator"
 class CommonAPIEducatorFields(BaseModel):
     first_name: Optional[str] = None
     last_name: Optional[str] = None
-    email: Optional[list[str]] = None
     details: Optional[str] = None
     home_address: Optional[str] = None
     target_community: Optional[str] = None
@@ -43,6 +42,11 @@ class CreateAPIEducatorFields(CommonAPIEducatorFields):
 
 class APIEducatorFields(CommonAPIEducatorFields):
     full_name: Optional[str] = None
+    all_emails: Optional[list[str]] = None
+    primary_personal_email: Optional[str] = None
+    other_personal_emails: Optional[list[str]] = None
+    primary_wildflower_email: Optional[str] = None
+    wildflowerschools_email: Optional[str] = None
     source: Optional[list[str]] = None
     source_other: Optional[str] = None
     montessori_certified: Optional[bool] = None
@@ -56,7 +60,7 @@ class APIEducatorMetaFields(BaseModel):
     copy_field(APIEducatorFields, "full_name", __annotations__)
     copy_field(CommonAPIEducatorFields, "first_name", __annotations__)
     copy_field(CommonAPIEducatorFields, "last_name", __annotations__)
-    copy_field(CommonAPIEducatorFields, "email", __annotations__)
+    copy_field(APIEducatorFields, "all_emails", __annotations__)
 
 
 class APIEducatorRelationships(BaseModel):
