@@ -2,8 +2,7 @@ from datetime import date
 from enum import Enum
 from typing import Optional, Union
 
-from pydantic import BaseModel
-
+from .base_model import BaseModel
 from . import response as response_models
 
 MODEL_TYPE = "educator_school"
@@ -21,6 +20,7 @@ class APIEducatorSchoolRoles(str, Enum):
 class CommonAPIEducatorSchoolFields(BaseModel):
     start_date: Optional[date] = None
     end_date: Optional[date] = None
+    email: Optional[str] = None
     roles: Optional[list[APIEducatorSchoolRoles]] = None
     currently_active: Optional[bool] = None
     mark_for_deletion: Optional[bool] = None
