@@ -1,7 +1,7 @@
 from datetime import date
 from typing import Optional
 
-from pydantic import BaseModel
+from .base_model import BaseModel
 
 MODEL_TYPE = "guides_school"
 
