@@ -1,7 +1,6 @@
 from typing import Optional, Union
 
-from pydantic import BaseModel
-
+from .base_model import BaseModel
 from . import response as response_models
 
 MODEL_TYPE = "hub"
