@@ -1,6 +1,6 @@
 from typing import Optional, Union
 
-from pydantic import BaseModel
+from .base_model import BaseModel
 
 
 class APILinks(BaseModel):
@@ -24,7 +24,7 @@ class APILinksAndData(APILinks):
 
 class APIData(APIDataWithFields):
     fields: dict
-    relationships: dict[str, Union[APILinksAndData, APILinks]]
+    relationships: dict[str, Optional[Union[APILinksAndData, APILinks]]]
     links: dict[str, Optional[str]]
 
 
