@@ -1,6 +1,6 @@
 from typing import Type
 
-from pydantic import BaseModel
+from .base_model import BaseModel
 
 
 def copy_field(from_model: Type[BaseModel], fname: str, to_annotations: dict):
